import { PaginationEmits, PaginationProps } from './components/VueyePagination/api';
import { InferDefaults, Row, SlotHeader, SlotRow, FlattenKeys, ColumnHeader, FlattenObject } from './types';
export type FilterMethod<TData extends Record<string, unknown>> = (query: string | undefined, item: FlattenObject<TData>, filterBy?: FlattenKeys<TData>[]) => boolean | undefined;
export declare function defineFilterMethod<TData extends Record<string, unknown>>(filterMethod: FilterMethod<TData>): (query: string | undefined, item: FlattenObject<TData>, filterBy?: FlattenKeys<TData>[]) => boolean | undefined;
export type VueyeTableProps<TData extends Record<string, unknown> = Record<string, unknown>, TColumn extends ColumnHeader<TData> = ColumnHeader<TData>> = {
    data: TData[];
    columnHeaders?: TColumn[];
    itemValue?: string;
    perPage?: number;
    currentPage?: number;
    perPageOptions?: number[];
    loading?: boolean;
    selected?: TData[] | Row[] | null;
    selectMode?: 'page' | 'all';
    caption?: string;
    summary?: string;
    filterQuery?: string;
    filterBy?: FlattenKeys<TData>[];
    filterMethod?: FilterMethod<TData>;
};
export declare function getVueyeTablePropDefaults<TData extends Record<string, unknown>, TColumn extends ColumnHeader<TData>>(): InferDefaults<VueyeTableProps<TData, TColumn>>;
export type VueyeTableEmits<T> = PaginationEmits & {
    (event: 'update:loading', value: boolean): void;
    (event: 'update:selected', value: T[]): void;
};
export type VueyeTableSlots<TData extends Record<string, any>> = SlotHeader<TData> & SlotRow<TData> & {
    caption: () => any;
    summary: () => any;
    loading: () => any;
    empty: () => any;
    pagination: (props: {
        pagination: PaginationProps;
    }) => any;
};
